# PySheets

PySheets is a spreadsheet UI for Python, implemented in Python, running logic and saving data in the browser, using PyScript and IndexedDB.
  
# Installation

```
pip install pysheets-app
```

# Using

```
python3 -m pysheets
```

This should open http://localhost:8081/ in your browser and show a button to create a new sheet.

Things to try:
 - Change the sheet name
 - Add literal values in the sheet
 - Import a sheet from the web (see the AI section)

